@@ -1,5 +1,6 @@
 # adapted from https://github.com/ptrblck/pytorch_misc/blob/master/shared_dict.py
 from multiprocessing import Manager
+
 from .cached_dataset import CachedDataset
 
 
@@ -9,7 +10,7 @@ class SharedDictDataset(CachedDataset):
         manager = Manager()
         self.shared_dict = manager.dict()
 
-    def _getitem_impl(self, idx):
+    def _cached_getitem(self, idx):
         if idx not in self.shared_dict:
             sample = self.dataset[idx]
             self.shared_dict[idx] = sample
@@ -18,4 +19,4 @@ class SharedDictDataset(CachedDataset):
         return sample
 
     def dispose(self):
-        self.shared_dict.clear()
\ No newline at end of file
+        self.shared_dict.clear()
